summaryrefslogtreecommitdiffstats
path: root/qt/SciListBox.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qt/SciListBox.cpp')
-rw-r--r--qt/SciListBox.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/qt/SciListBox.cpp b/qt/SciListBox.cpp
index ef2475b..f873d7c 100644
--- a/qt/SciListBox.cpp
+++ b/qt/SciListBox.cpp
@@ -98,7 +98,7 @@ void ListBoxX::Create(Window &parent,int,Point,int,bool)
void ListBoxX::SetAverageCharWidth(int)
{
// We rely on TQListBox::tqsizeHint() for the size of the list box rather
// than make calculations based on the average character width and the
// number of visible rows.
}
@@ -121,7 +121,7 @@ PRectangle ListBoxX::GetDesiredRect()
if (slb)
{
- TQSize sh = slb -> tqsizeHint();
+ TQSize sh = slb -> sizeHint();
rc.right = sh.width();
rc.bottom = sh.height();
@@ -98,7 +98,7 @@ void ListBoxX::Create(Window &parent,int,Point,int,bool)
void ListBoxX::SetAverageCharWidth(int)
{
- // We rely on TQListBox::tqsizeHint() for the size of the list box rather
+ // We rely on TQListBox::sizeHint() for the size of the list box rather
// than make calculations based on the average character width and the
// number of visible rows.